#
# spec file for package python-deap
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python36 1
Name:           python-deap
Version:        1.3.1
Release:        4.8
Summary:        Distributed Evolutionary Algorithms in Python
License:        LGPL-3.0-only
URL:            https://github.com/DEAP/deap
Source:         https://files.pythonhosted.org/packages/source/d/deap/deap-%{version}.tar.gz
# https://github.com/DEAP/deap/pull/507
Patch0:         python-deap-remove-nose.patch
# https://github.com/DEAP/deap/pull/507
Patch1:         python-deap-python3.patch
Patch2:         no2to3.patch
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
DEAP is intended to be an easy to use distributed evolutionary algorithm
library in the Python language. Its two main components are modular and
can be used separately. The first module is a Distributed Task Manager
(DTM), which is intended to run on cluster of computers. The second
part is the Evolutionary Algorithms in Python (EAP) framework.

%prep
%setup -q -n deap-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# failures only for 2.7; will have to be soved trough
# https://github.com/DEAP/deap/pull/507
# as well
%pytest_arch -k 'not (test_nsga3 or test_bin2float)'

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitearch}/*

%changelog
* Tue Mar  1 2022 Dirk Müller <dmueller@suse.com>
- add no2to3.patch for compatibility with newer setuptools
* Wed Apr 21 2021 Steve Kowalik <steven.kowalik@suse.com>
- Don't build for Python 3.6, due to no NumPy.
* Thu Sep 10 2020 pgajdos@suse.com
- remove nose, python3
- added patches
  fix https://github.com/DEAP/deap/pull/507
  + python-deap-python3.patch
  fix https://github.com/DEAP/deap/pull/507
  + python-deap-remove-nose.patch
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 1.3.1
  * Add Python 3.8 builds
  * Various documentation fixups
  * Added try except ImportError for collections.abc
  * The function itertools.repeat in bound.__init__ was called as
    'itertools.repeat', while the function was imported using
    'from itertools import repeat'
  * fix: first element of the pop is inserted twice
  * Use codecs for Python2 compat
* Wed Nov 20 2019 Todd R <toddrme2178@gmail.com>
- Initial version
